@@ -3,7 +3,7 @@
 checktriangleineq <- function(mat, warn=TRUE, indices = FALSE, tol = 1e-7) {
 	## Take care to get a matrix
 	mat <- dist2matrix(mat)
-	ind <- .Call(TMR_checktriangleineq, mat, as.integer(nrow(mat)), as.double(tol))
+	ind <- .Call(C_checktriangleineq, mat, as.integer(nrow(mat)), as.double(tol))
 	if(is.null(ind)){
 		return(TRUE)
 	}
