@@ -2,6 +2,6 @@
 ## PLOT OF THE SEQUENCE OF MODAL STATES
 ## ====================================
 
-seqmsplot <- function(seqdata, group=NULL, title=NULL, ...) {
-	seqplot(seqdata, group=group, type="ms", title=title, ...)
+seqmsplot <- function(seqdata, group = NULL, main = NULL, ...) {
+	seqplot(seqdata, group=group, type="ms", main=main, ...)
 }
