@@ -5,12 +5,12 @@
 seqxtract <- function(data, var, data.frame=FALSE) {
 	
 	## Extracting the sequences from the data set
-	if (missing(var) || is.null(var) || is.na(var)) 
+	if (missing(var) || is.null(var) || is.na(var[1]))
 		seqdata <- data
-	else 
+	else
 		seqdata <- subset(data,,var)
 
-	if (data.frame==FALSE) 
+	if (data.frame==FALSE)
 		seqdata <- as.matrix(seqdata)
 
 	return(seqdata)
